@@ -137,7 +137,7 @@ void kpColorCellsBase::setRowColumnCounts (int rows, int columns)
     const int oldRows = rowCount (), oldCols = columnCount ();
     const int newRows = rows, newCols = columns;
 #if DEBUG_KP_COLOR_CELLS_BASE
-    qCDebug(kpLogMisc) << "oldRows=" << oldRows << "oldCols=" << oldCols
+    qCDebug(kpLogColorCollection) << "oldRows=" << oldRows << "oldCols=" << oldCols
         << "newRows=" << newRows << "newCols=" << newCols;
 #endif
 
@@ -383,7 +383,7 @@ int kpColorCellsBase::positionToCell(const QPoint &pos, bool ignoreBorders,
 
     const int r = indexAt (pos).row (), c = indexAt (pos).column ();
 #if DEBUG_KP_COLOR_CELLS_BASE
-    qCDebug(kpLogMisc) << "r=" << r << "c=" << c;
+    qCDebug(kpLogColorCollection) << "r=" << r << "c=" << c;
 #endif
 
     if (r == -1 || c == -1)
@@ -421,14 +421,14 @@ void kpColorCellsBase::mouseMoveEvent( QMouseEvent *e )
             if (cell != -1)
             {
             #if DEBUG_KP_COLOR_CELLS_BASE
-               qCDebug(kpLogMisc) << "beginning drag from cell=" << cell
+               qCDebug(kpLogColorCollection) << "beginning drag from cell=" << cell
                          << "color: isValid=" << d->colors [cell].isValid ()
                          << " rgba=" << (int *) d->colors [cell].rgba();
             #endif
                Q_ASSERT (d->colors[cell].isValid());
                KColorMimeData::createDrag(d->colors[cell], this)->start(Qt::CopyAction | Qt::MoveAction);
             #if DEBUG_KP_COLOR_CELLS_BASE
-               qCDebug(kpLogMisc) << "finished drag";
+               qCDebug(kpLogColorCollection) << "finished drag";
             #endif
             }
         }
@@ -459,7 +459,7 @@ static void SetDropAction (QWidget *self, QDropEvent *event)
 void kpColorCellsBase::dragEnterEvent( QDragEnterEvent *event)
 {
 #if DEBUG_KP_COLOR_CELLS_BASE
-     qCDebug(kpLogMisc) << "kpColorCellsBase::dragEnterEvent() acceptDrags="
+     qCDebug(kpLogColorCollection) << "kpColorCellsBase::dragEnterEvent() acceptDrags="
                << d->acceptDrags
                << " canDecode=" << KColorMimeData::canDecode(event->mimeData());
 #endif
@@ -472,7 +472,7 @@ void kpColorCellsBase::dragEnterEvent( QDragEnterEvent *event)
 void kpColorCellsBase::dragMoveEvent (QDragMoveEvent *event)
 {
 #if DEBUG_KP_COLOR_CELLS_BASE
-     qCDebug(kpLogMisc) << "kpColorCellsBase::dragMoveEvent() acceptDrags="
+     qCDebug(kpLogColorCollection) << "kpColorCellsBase::dragMoveEvent() acceptDrags="
                << d->acceptDrags
                << " canDecode=" << KColorMimeData::canDecode(event->mimeData());
 #endif
@@ -490,7 +490,7 @@ void kpColorCellsBase::dropEvent( QDropEvent *event)
          positionToCell (d->mousePos, true) :
          -1;
 #if DEBUG_KP_COLOR_CELLS_BASE
-     qCDebug(kpLogMisc) << "kpColorCellsBase::dropEvent()"
+     qCDebug(kpLogColorCollection) << "kpColorCellsBase::dropEvent()"
                << "color: rgba=" << (const int *) c.rgba () << "isValid=" << c.isValid()
                << "source=" << event->source () << "dragSourceCell=" << dragSourceCell;
 #endif
@@ -499,7 +499,7 @@ void kpColorCellsBase::dropEvent( QDropEvent *event)
 
           int cell = positionToCell(event->pos(), true, true/*allow empty cell*/);
      #if DEBUG_KP_COLOR_CELLS_BASE
-          qCDebug(kpLogMisc) << "\tcell=" << cell;
+          qCDebug(kpLogColorCollection) << "\tcell=" << cell;
      #endif
           // TODO: I believe kdelibs forgets to do this.
           if (cell == -1)
@@ -513,7 +513,7 @@ void kpColorCellsBase::dropEvent( QDropEvent *event)
 	  setColor(cell,c);
 
     #if DEBUG_KP_COLOR_CELLS_BASE
-          qCDebug(kpLogMisc) << "\tdropAction=" << event->dropAction ()
+          qCDebug(kpLogColorCollection) << "\tdropAction=" << event->dropAction ()
                     << "destOldColor.rgba=" << (const int *) destOldColor.rgba ();
     #endif
           if (event->dropAction () == Qt::MoveAction && dragSourceCell != -1) {
